@@ -82,8 +82,17 @@ extern int __REDIRECT_NTH (__ttyname_r_alias, (int __fd, char *__buf,
 #include "ioctl_tree.h"
 
 #ifdef __GLIBC__
+
+/* __USE_TIME64_REDIRECTS was introduced in glibc 2.39.9. With older releases we need to look at
+ * __USE_TIME_BITS64 instead, but the latter is always defined in 2.39.9 now. So make some guesswork
+ * and define the former when appropriate. */
+#if !defined(__USE_TIME64_REDIRECTS) && defined(__USE_TIME_BITS64) && __TIMESIZE == 32
+#pragma message "Defining backwards compatibility shim __USE_TIME64_REDIRECTS for glibc < 2.39.9"
+#define __USE_TIME64_REDIRECTS 1
+#endif
+
 /* Fixup for making a mess with __REDIRECT above */
-#ifdef __USE_TIME_BITS64
+#ifdef __USE_TIME64_REDIRECTS
 #define clock_gettime __clock_gettime64
 extern int clock_gettime(clockid_t clockid, struct timespec *tp);
 #endif
@@ -1420,7 +1429,7 @@ WRAP_STAT(,64);
 WRAP_STAT(l,64);
 WRAP_FSTATAT(,64);
 WRAP_FOPEN(,64);
-#if defined(__USE_FILE_OFFSET64) && defined(__USE_TIME_BITS64)
+#if defined(__USE_FILE_OFFSET64) && defined(__USE_TIME64_REDIRECTS)
 #define stat64_time64 stat64
 WRAP_STAT(__,64_time64);
 WRAP_STAT(__l,64_time64);
